
//---------------------------------------------------------------------------------------
//-------------------------------  PULSADOR   -------------------------------------------
//---------------------------------------------------------------------------------------
volatile int8_t EncoderVal = 0; // Esta variable incrementa o decrementa dependiendo de la rotación del encoder
uint8_t StatusSwitch = 0;       // Máquina de estados
uint8_t PressButton = 0;        // Variable que se pone a 1 en pulsación corta y a 2 en larga
uint8_t TimePressed = 0;        // Contador de 10mseg que la tecla está pulsada

void leerswitch(void) {

  switch (StatusSwitch) {
    case 0:
      if (!digitalRead(PinMenu))StatusSwitch++;
      return;
    case 1:
    case 2:
    case 3:
      StatusSwitch++;
      TimePressed = 0;
      return;
    case 4:
      if (!digitalRead(PinMenu)) {
        TimePressed++;
        if (TimePressed >= 60) {
          PressButton = 2;
          StatusSwitch = 5;
        }
      }
      else {
        PressButton = 1;
        StatusSwitch = 0;
      }
      return;
    case 5:
      if (digitalRead(PinMenu))StatusSwitch = 0; // volvemos al estado inicial
      return;
  }
}

const char StepSizeStr[][12] = {
  "STEP    1Hz",
  "STEP   10Hz",
  "STEP  100Hz",
  "STEP   1kHz",
  "STEP  10kHz",
  "STEP 100kHz",
  "STEP   1MHz"
};

const uint32_t StepSize[] = {1L, 10L, 100L, 1000L, 10000L, 100000L, 1000000L};

/********************************************************************************************************
  Formatea con punto en los miles y prescindir última cifra si es necesario
  Ej... 10,345.00 serían 10Mhz 345.000 hz
  recibe como parámetro un puntero a un número de 32 bits y el puntero donde se devuelve el string
*********************************************************************************************************/
void PrintFreq(uint32_t * Fr, char *c) {
  char Herz[10]; // reservamos un string de 10 caracteres de largo
  int8_t p;

  Herz[0] = ' '; // espacios en blanco para rellenar por la izquierda las cifras no utilizadas
  Herz[1] = ' ';
  Herz[2] = ' ';
  Herz[3] = ' ';
  Herz[5] = '.';

  // sprintf(c, "%ld", *Fr) ==> convierte un número en un string. El array c es el string de destino
  // "%ld" es el formato de la conversión,%=control l=long d= decimal, *Fr apunta al número a convertir.
  // sprintf(c, "la frecuencia es %ld herzios", *Fr); pondría en el array c= "la frecuencia es 54789 herzios"
  
  sprintf(c, "%ld", *Fr);            // convert freq to string. http://es.cppreference.com/w/cpp/io/c/fprintf
  p = strlen(c);                     // determine longitud del string
  switch (p) {
    case 5:
      strncpy(Herz + 3, c , 2);      //http://www.cplusplus.com/reference/cstring/strncpy/
      strncpy(Herz + 6, c + 2 , 3);  // puntero a destino Herz+6, desde el origen c+2, 3 elementos
      break;
    case 6:
      strncpy(Herz + 2, c , 3); 
      strncpy(Herz + 6, c + 3 , 3);  // puntero a destino Herz+6, desde el origen c+3, 3 elementos
      break;
    case 7:
      Herz[0] = c[0];
      Herz[1] = ',';
      strncpy(Herz + 2, c + 1 , 3);
      strncpy(Herz + 6, c + 4 , 3);
      break;
    case 8:
      strncpy(Herz , c, 2);
      Herz[2] = ',';
      strncpy(Herz + 3, c + 2 , 3);
      Herz[6] = '.';
      strncpy(Herz + 7, c + 5 , 2);
  }
  Herz[9] = 0;        // todo string tiene que terminar en 0
  strcpy(c, Herz);    // se copia el string formateado en el puntero. http://www.cplusplus.com/reference/cstring/strcpy/
}

/***********************************************************************************
   Esta rutina pinta la pantalla en función del menú
   No recibe parámetros ya que utiliza el estado de la máquina de estados principal
 * *********************************************************************************
*/
void PrintMenu (void) {
  char LCDstr[10];
  PrintFreq(&vfo_t, LCDstr);
  
  // sprintf(LCDstr, "f= %ld Hz bat= %d V", vfo_t, Vbat);
  // vfo_t=103 bat=13 ==>LCDstr quedaría así "f= 103 Hz bat=13 V"
  
  u8g2.firstPage();
  do {
    // Pantalla principal ---------------------------
    u8g2.setFont(u8g2_font_logisoso22_tn);
    u8g2.drawStr(0, 24, LCDstr);

    u8g2.setFont(u8g2_font_6x13_t_hebrew);
    u8g2.drawStr(5, 40, StepSizeStr[steps]);

    // Linea de estado inferior --------------------
    u8g2.drawHLine(0, 50, 128);
    u8g2.drawStr(20,62,"www.ea3gcy.com");
  } while ( u8g2.nextPage() );
  return;
}

uint8_t IsButtonPressed() {
  uint8_t tmp;
  if (PressButton != 0) {
    tmp = PressButton;
    PressButton = 0;
    return tmp;
  }
  return 0;
}

//---------------------------------------------------------------------------------------
//-------------------------------  BASE DE TIEMPO  --------------------------------------
//---------------------------------------------------------------------------------------

unsigned long tiempoAhora10mseg = 0;
boolean Tiempo10mseg(void) {
  unsigned long tmp;
  tmp = micros();
  if ((tmp - tiempoAhora10mseg) >= 10000UL) {
    tiempoAhora10mseg = tmp;
    return 1;
  }
  return 0;
}

